@@ -35,7 +35,7 @@ Usage::
     describe_users_paginator: DescribeUsersPaginator = client.get_paginator("describe_users")
     ```
 """
-from mypy_boto3_workdocs.client import WorkDocsClient as Client, WorkDocsClient
+from mypy_boto3_workdocs.client import WorkDocsClient
 from mypy_boto3_workdocs.paginator import (
     DescribeActivitiesPaginator,
     DescribeCommentsPaginator,
@@ -48,6 +48,8 @@ from mypy_boto3_workdocs.paginator import (
     DescribeUsersPaginator,
 )
 
+Client = WorkDocsClient
+
 
 __all__ = (
     "Client",
